<center>- frequently-used function library -</center>

# ✨ meo

## install

**Pypi:**

```sh
pip install meo -i https://pypi.org/simple
```

**使用豆瓣源安装：**

```sh
pip install meo -i https://pypi.douban.com/simple
```

## 1. Document
+ [0.x_en](./docs/0.x_en.md)
+ [0.x_中文文档](./docs/0.x_zh.md)
